@@ -1,15 +1,15 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::HashViewer ;
-BEGIN {
-  $Config::Model::Tk::HashViewer::VERSION = '1.325';
+{
+  $Config::Model::Tk::HashViewer::VERSION = '1.340';
 }
 
 use strict;
@@ -54,7 +54,7 @@ sub Populate {
 				     -height => 10,
 				   ) ->pack(@fbe1) ;
 
-    foreach my $c ($hash->get_all_indexes) {
+    foreach my $c ($hash->fetch_all_indexes) {
 	$rt->insert('end', $c."\n" ) ;
     }
 
