@@ -1,15 +1,15 @@
-# 
+#
 # This file is part of Config-Model-TkUI
-# 
-# This software is Copyright (c) 2010 by Dominique Dumont.
-# 
+#
+# This software is Copyright (c) 2013 by Dominique Dumont.
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU Lesser General Public License, Version 2.1, February 1999
-# 
+#
 package Config::Model::Tk::NodeEditor ;
-BEGIN {
-  $Config::Model::Tk::NodeEditor::VERSION = '1.310';
+{
+  $Config::Model::Tk::NodeEditor::VERSION = '1.340';
 }
 
 use strict;
@@ -19,8 +19,9 @@ use Carp ;
 use Tk::Pane ;
 use Tk::Balloon;
 use Text::Wrap;
+use Config::Model::Tk::NoteEditor ;
 
-use base qw/Tk::Frame Config::Model::Tk::AnyViewer/;
+use base qw/Config::Model::Tk::NodeViewer/;
 use subs qw/menu_struct/ ;
 
 
@@ -30,7 +31,7 @@ my @fbe1 = qw/-fill both -expand 1/ ;
 my @fxe1 = qw/-fill x    -expand 1/ ;
 my @fx   = qw/-fill x    -expand 0/ ;
 
-my $logger = Log::Log4perl::get_logger(__PACKAGE__);
+my $logger = Log::Log4perl::get_logger("Tk::NodeEditor");
 
 sub ClassInit {
     my ($cw, $args) = @_;
@@ -56,10 +57,17 @@ sub Populate {
 
     $cw->fill_pane ;
 
+    # insert a widget for "accepted" elements
+    my @rexp = $node->accept_regexp ;
+    if (@rexp) {
+	$cw-> add_accept_entry(@rexp) ;
+    }
+
     # add adjuster
     #require Tk::Adjuster;
     #$cw -> Adjuster()->pack(-fill => 'x' , -side => 'top') ;
 
+    $cw->ConfigModelNoteEditor( -object => $node )->pack;
     $cw->add_info_button()->pack(@fxe1, qw/-anchor n/) ;
 
     if ($node->parent) {
@@ -69,7 +77,8 @@ sub Populate {
     else {
 	$cw->add_help(class   => $node->get_help)->pack(@fx) ;
     }
-    $cw->SUPER::Populate($args) ;
+    # don't call directly SUPER::Populate as it's LeafViewer's populate
+    $cw->Tk::Frame::Populate($args) ;
 }
 
 sub reload {
@@ -84,22 +93,25 @@ sub fill_pane {
 
     my $exp = $cw->parent->parent->parent->parent->get_experience ;
 
-    my %old_elt = map { ($_ => 1) } keys %{$cw->{elt_widgets}|| {} } ;
+    my %is_elt_drawn = map { ($_ => 1) } keys %{$cw->{elt_widgets}|| {} } ;
 
     my %values;
     my %modified ;
-    my $old_f ;
+    my $prev_elt ;
 
     foreach my $c ($node->get_element_name(for => $exp)) {
-	next if delete $old_elt{$c} ;
+	if (delete $is_elt_drawn{$c}) { 
+	    $prev_elt = $c ;
+	    next;
+	} ; 
 
 	my $type = $node->element_type($c) ;
 	my $elt_path = $cw->{path}.'.'.$c ;
 
-	my @after = $old_f ? ( -after => $old_f ) : () ;
-	my $f = $elt_pane->Frame(-relief=> 'groove', -borderwidth => 1)
-	  ->pack(-side =>'top',@fx,@after) ;
-	$old_f = $f ;
+	my @after = defined $prev_elt ? ( -after => $cw->{elt_widgets}{$prev_elt} ) : () ;
+        $prev_elt = $c ;
+	my $f = $elt_pane->Frame(-relief=> 'groove', -borderwidth => 1);
+	$f ->pack(-side =>'top',@fx,@after) ;
 
 	$cw->{elt_widgets}{$c} = $f ;
 	my $label = $f -> Label(-text => $c,-width=> 22, -anchor => 'w') ;
@@ -110,9 +122,9 @@ sub fill_pane {
 
 	if ($type eq 'leaf') {
 	    my $leaf = $node->fetch_element($c) ;
-	    my $v = eval {$node->fetch_element_value($c)} ;
+	    my $v = $node->fetch_element_value(name => $c, check  => 'no') ;
 	    my $store_sub = sub {$leaf->store($v); 
-				 $cw->{store_cb}->(1,undef,$elt_path);
+				 $cw->{store_cb}->($elt_path);
 				 $cw->fill_pane;
 			     };
 	    my $v_type = $leaf->value_type ;
@@ -152,7 +164,7 @@ sub fill_pane {
 		    -command => $edit_sub) ;
 	$edb -> pack(-anchor => 'w');
 
-	my $content = $type eq 'leaf' ? $obj->fetch_no_check || ''
+	my $content = $type eq 'leaf' ? $obj->fetch( check => 'no') || ''
 	            : $type eq 'node' ? $node->config_class_name
 	            :                   $type ;
  	$cw->Balloon(-state => 'balloon') 
@@ -160,20 +172,35 @@ sub fill_pane {
     }
 
     # destroy leftover widgets (may occur with warp mechanism)
-    map {my $w = delete $cw->{elt_widgets}{$_};$w->destroy } keys %old_elt ;
+    map {my $w = delete $cw->{elt_widgets}{$_};$w->destroy } keys %is_elt_drawn ;
 }
 
-sub get_info {
-    my $cw = shift ;
+sub add_accept_entry {
+    my ($cw,@rexp) = @_ ;
 
     my $node = $cw->{node} ;
+    my $f = $cw->Frame(-relief=> 'groove', -borderwidth => 1);
+    $f ->pack(-side =>'top',@fx) ;
 
-    my @items = ('type : '. $node->get_type ,
-		 'class name : '.$node->config_class_name ,
-		);
+    my $accepted = '' ;
+    $f -> Label(-text => 'accept : /'.join('/, /',@rexp).'/') -> pack ;
 
-    return $node->element_name,@items ;
+    my $e = $f->Entry(-textvariable => \$accepted)
+		  ->pack(qw/-side left -anchor w/,@fxe1) ;
+    my $sub = sub {
+    	return unless $accepted ;
+    	my $ok = 0 ;
+    	map { $ok ++ if $accepted =~ /^$_$/ } @rexp ; 
+	if (not $ok) {
+	    die "Cannot accept $accepted, it does not match any accepted regexp\n";
+	}
+    	$node->fetch_element($accepted); 
+	$cw->{store_cb}->();
+	$cw->fill_pane; 
+	$cw->{pane}->yview(moveto => 1);
+    };
+    
+    $e->bind("<Return>"   => $sub) ;
 }
 
-
 1;
